# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from cloudflare import Cloudflare, AsyncCloudflare
from tests.utils import assert_matches_type

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestContentScanning:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @parametrize
    def test_method_disable(self, client: Cloudflare) -> None:
        content_scanning = client.content_scanning.disable(
            zone_id="023e105f4ecef8ad9ca31a8372d0c353",
        )
        assert_matches_type(object, content_scanning, path=["response"])

    @parametrize
    def test_raw_response_disable(self, client: Cloudflare) -> None:
        response = client.content_scanning.with_raw_response.disable(
            zone_id="023e105f4ecef8ad9ca31a8372d0c353",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        content_scanning = response.parse()
        assert_matches_type(object, content_scanning, path=["response"])

    @parametrize
    def test_streaming_response_disable(self, client: Cloudflare) -> None:
        with client.content_scanning.with_streaming_response.disable(
            zone_id="023e105f4ecef8ad9ca31a8372d0c353",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            content_scanning = response.parse()
            assert_matches_type(object, content_scanning, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_path_params_disable(self, client: Cloudflare) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `zone_id` but received ''"):
            client.content_scanning.with_raw_response.disable(
                zone_id="",
            )

    @parametrize
    def test_method_enable(self, client: Cloudflare) -> None:
        content_scanning = client.content_scanning.enable(
            zone_id="023e105f4ecef8ad9ca31a8372d0c353",
        )
        assert_matches_type(object, content_scanning, path=["response"])

    @parametrize
    def test_raw_response_enable(self, client: Cloudflare) -> None:
        response = client.content_scanning.with_raw_response.enable(
            zone_id="023e105f4ecef8ad9ca31a8372d0c353",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        content_scanning = response.parse()
        assert_matches_type(object, content_scanning, path=["response"])

    @parametrize
    def test_streaming_response_enable(self, client: Cloudflare) -> None:
        with client.content_scanning.with_streaming_response.enable(
            zone_id="023e105f4ecef8ad9ca31a8372d0c353",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            content_scanning = response.parse()
            assert_matches_type(object, content_scanning, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_path_params_enable(self, client: Cloudflare) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `zone_id` but received ''"):
            client.content_scanning.with_raw_response.enable(
                zone_id="",
            )


class TestAsyncContentScanning:
    parametrize = pytest.mark.parametrize("async_client", [False, True], indirect=True, ids=["loose", "strict"])

    @parametrize
    async def test_method_disable(self, async_client: AsyncCloudflare) -> None:
        content_scanning = await async_client.content_scanning.disable(
            zone_id="023e105f4ecef8ad9ca31a8372d0c353",
        )
        assert_matches_type(object, content_scanning, path=["response"])

    @parametrize
    async def test_raw_response_disable(self, async_client: AsyncCloudflare) -> None:
        response = await async_client.content_scanning.with_raw_response.disable(
            zone_id="023e105f4ecef8ad9ca31a8372d0c353",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        content_scanning = await response.parse()
        assert_matches_type(object, content_scanning, path=["response"])

    @parametrize
    async def test_streaming_response_disable(self, async_client: AsyncCloudflare) -> None:
        async with async_client.content_scanning.with_streaming_response.disable(
            zone_id="023e105f4ecef8ad9ca31a8372d0c353",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            content_scanning = await response.parse()
            assert_matches_type(object, content_scanning, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_path_params_disable(self, async_client: AsyncCloudflare) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `zone_id` but received ''"):
            await async_client.content_scanning.with_raw_response.disable(
                zone_id="",
            )

    @parametrize
    async def test_method_enable(self, async_client: AsyncCloudflare) -> None:
        content_scanning = await async_client.content_scanning.enable(
            zone_id="023e105f4ecef8ad9ca31a8372d0c353",
        )
        assert_matches_type(object, content_scanning, path=["response"])

    @parametrize
    async def test_raw_response_enable(self, async_client: AsyncCloudflare) -> None:
        response = await async_client.content_scanning.with_raw_response.enable(
            zone_id="023e105f4ecef8ad9ca31a8372d0c353",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        content_scanning = await response.parse()
        assert_matches_type(object, content_scanning, path=["response"])

    @parametrize
    async def test_streaming_response_enable(self, async_client: AsyncCloudflare) -> None:
        async with async_client.content_scanning.with_streaming_response.enable(
            zone_id="023e105f4ecef8ad9ca31a8372d0c353",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            content_scanning = await response.parse()
            assert_matches_type(object, content_scanning, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_path_params_enable(self, async_client: AsyncCloudflare) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `zone_id` but received ''"):
            await async_client.content_scanning.with_raw_response.enable(
                zone_id="",
            )
